@@ -9,9 +9,7 @@ import numpy as np
 import requests
 
 from .__consumer import Consumer
-from .utils import AGGREGATED_OUTPUT_DIR
-
-FILE_METADATA = "{'key1':'value1', 'key2':'value2'}"
+from .utils import AGGREGATED_OUTPUT_DIR, FILE_METADATA
 
 
 class Client:
@@ -20,18 +18,13 @@ class Client:
                  host: str = "https://api.branchkey.com"):
 
         if credentials is None:
-            credentials = dict(leaf_name="guest", leaf_password="guest", tree_id="guest", branch_id="guest",
-                               queue_password="guest", host="response.branchkey.com", port=5672)
-        if 'response_host' in credentials:
-            credentials['host'] = credentials['response_host']
-        self.__leaf_name = credentials["leaf_name"]
-        self.__leaf_password = credentials["leaf_password"]
-        self.__tree_id = credentials["tree_id"]
-        self.__branch_id = credentials["branch_id"]
+            credentials = dict(leaf_name="guest", leaf_id="guest", leaf_session_token="guest",
+                               response_host="response.branchkey.com", port=5672)
 
-        self.__status = False
-        self.__access_token = None
-        self.__leaf_id = None
+        self.__leaf_name = credentials["leaf_name"]
+        self.__leaf_id = credentials["leaf_id"]
+        self.__leaf_session_token = credentials["leaf_session_token"]
+        self.__status = "unauthenticated"
 
         self.__api_host = host
         # Verify SSL certs
@@ -40,7 +33,8 @@ class Client:
         self.queue = Queue()
         self.__run_status = 'pause'
 
-        self.rabbit_credentials = credentials
+        self.rabbit_credentials = dict(
+            leaf_name=self.__leaf_name, leaf_id=self.__leaf_id, queue_password=self.__leaf_session_token, host=credentials["response_host"])
         self.consumer = None
         return
 
@@ -48,7 +42,8 @@ class Client:
         self.__run_status = status
 
     def disable_ssl_verification(self, enabled=False):
-        warnings.warn("[BranchKey] We highly recommend enabling ssl verification. Use this at your own risk.")
+        warnings.warn(
+            "[BranchKey] We highly recommend enabling ssl verification. Use this at your own risk.")
         self.__verify = enabled
         return self.__verify
 
@@ -85,61 +80,39 @@ class Client:
             file.seek(0)
             return True
 
-    def login(self):
+    def authenticate(self):
         try:
-            url = self.__api_host + "/v1/leaf/login"
+            url = self.__api_host + "/v1/leaf/authenticate"
             headers = {"accept": "application/json"}
-            data = json.dumps({
-                      "tree_id": self.__tree_id,
-                      "branch_id": self.__branch_id
-                    })
 
-            resp = requests.put(url, data=data, headers=headers,
-                                auth=(self.__leaf_name, self.__leaf_password), verify=self.__verify)
+            resp = requests.get(url, headers=headers,
+                                auth=(self.__leaf_id, self.__leaf_session_token), verify=self.__verify)
 
-            if resp.status_code != HTTPStatus.CREATED:
+            print(f"received resp code form auth: {resp.status_code}")
+            if resp.status_code != HTTPStatus.OK:
                 raise Exception(resp.json())
 
-            login_data = resp.json()["data"]
+            authenticate_data = resp.json()["data"]
             try:
-                self.__leaf_id = login_data["id"]
-                self.__access_token = login_data["access_token"]
-                self.__status = login_data["status"]
-                self.rabbit_credentials["queue_password"] = self.__access_token
-                self.rabbit_credentials["leaf_id"] = self.__leaf_id
-                consumer = Consumer(self.rabbit_credentials, self.queue, self.__update_run_status)
+                self.__status = "authenticated"
+                self.rabbit_credentials["tree_id"] = authenticate_data["tree_id"]
+                self.rabbit_credentials["branch_id"] = authenticate_data["branch_id"]
+                consumer = Consumer(self.rabbit_credentials,
+                                    self.queue, self.__update_run_status)
                 self.consumer = consumer.spawn_consumer_thread()
-                return self.__status == "logged_in"
+                return True
             except Exception as e:
-                raise Exception(f"Failed to parse response from login: {e}")
+                raise Exception(
+                    f"Failed to parse response from authenticate API: {e}")
 
         except Exception as e:
-            msg = "Login failed for {}: {}".format(self.__leaf_name, e)
+            msg = "Authentication failed for leaf {}: {}".format(
+                self.__leaf_name, e)
             logging.error(msg)
             return False
 
-    def logout(self):
-        if not self.__status == "logged_in" or not self.__access_token:
-            msg = "Logout failed for {}: not logged in or no access_token present".format(self.__leaf_name)
-            raise Exception(msg)
-        try:
-            url = self.__api_host + "/v1/leaf/logout"
-
-            resp = requests.put(url, auth=(self.__leaf_id, self.__access_token), verify=self.__verify)
-
-            if resp.status_code != HTTPStatus.OK:
-                raise Exception(f"{resp.json()['message']}")
-
-            self.__access_token = None
-            self.__status = "logged_out"
-            return True
-
-        except Exception as e:
-            msg = "Logout failed for {}: {}".format(self.__leaf_name, e)
-            raise Exception(msg)
-
     def file_upload(self, file_path):
-        if self.__status == "logged_in":
+        if self.__status == "authenticated":
             try:
                 with open(file_path, mode="rb") as f:
                     self.validate_weight_shape(f)
@@ -152,7 +125,7 @@ class Client:
 
                     resp = requests.post(
                         url, files=file, data=data, headers=headers,
-                        auth=(self.__leaf_id, self.__access_token), verify=self.__verify)
+                        auth=(self.__leaf_id, self.__leaf_session_token), verify=self.__verify)
                     f.close()
 
                     if resp.status_code != HTTPStatus.CREATED:
@@ -161,14 +134,16 @@ class Client:
                         return resp.json()["data"]["file_id"]
 
             except Exception as e:
-                msg = "File Upload failed for {} for file {}: {}".format(self.__leaf_name, file_path, e)
+                msg = "File Upload failed for leaf {} for file {}: {}".format(
+                    self.__leaf_name, file_path, e)
                 raise Exception(msg)
         else:
-            msg = "File Upload failed for leaf {} : {}".format(self.__leaf_name, "leaf not logged in")
+            msg = "File Upload failed for leaf {} : {}".format(
+                self.__leaf_name, "leaf not authenticated")
             raise Exception(msg)
 
     def file_download(self, file_id):
-        if self.__status == "logged_in":
+        if self.__status == "authenticated":
             try:
                 if not os.path.exists(AGGREGATED_OUTPUT_DIR):
                     os.makedirs(AGGREGATED_OUTPUT_DIR)
@@ -176,24 +151,35 @@ class Client:
                 url = self.__api_host + "/v1/file/download/" + file_id
                 headers = {"accept": "*/*S"}
                 resp = requests.get(url, headers=headers,
-                                    auth=(self.__leaf_id, self.__access_token), verify=self.__verify)
+                                    auth=(self.__leaf_id, self.__leaf_session_token), verify=self.__verify)
 
                 if resp.status_code != HTTPStatus.OK:
                     raise Exception(resp.json()["error"])
 
+                try:
+                    download_url = resp.json()["data"]["download_url"]
+                except Exception as e:
+                    raise Exception(
+                        f"Failed to parse response from download API: {resp.json()}")
+
+                resp = requests.get(download_url)
                 if len(resp.content) == 0:
                     raise Exception("file not received")
 
-                f = open(AGGREGATED_OUTPUT_DIR + '/' + file_id, 'wb')
+                f = open(AGGREGATED_OUTPUT_DIR +
+                         '/' + file_id + ".npy", 'wb')
                 f.write(resp.content)
                 f.close()
-
+                print(f"downloaded file {file_id}")
                 return True
+
             except Exception as e:
-                msg = "File Download failed for {} for file {}: {}".format(self.__leaf_name, file_id, e)
+                msg = "File Download failed for leaf {} for file {}: {}".format(
+                    self.__leaf_name, file_id, e)
                 raise Exception(msg)
         else:
-            msg = "File Download failed for leaf {} : {}".format(self.__leaf_name, "leaf not logged in")
+            msg = "File Download failed for leaf {} : {}".format(
+                self.__leaf_name, "leaf not authenticated")
             raise Exception(msg)
 
     @property
@@ -201,12 +187,12 @@ class Client:
         return self.__leaf_id
 
     @property
-    def access_token(self):
-        return self.__access_token
+    def session_token(self):
+        return self.__leaf_session_token
 
     @property
-    def is_logged_in(self):
-        return self.__status == "logged_in"
+    def is_authenticated(self):
+        return self.__status == "authenticated"
 
     @property
     def run_status(self):
